package Mnet::Opts::Set::Debug;

=head1 NAME

Mnet::Opts::Set::Debug - Use this module to enable --debug option

=head1 SYNOPSIS

    use Mnet::Opts::Set::Debug;

=head1 DESCRIPTION

This module can be used as a pragma to enable the L<Mnet::Log> --debug option.

=cut

# required modules
use warnings;
use strict;

=head1 SEE ALSO

L<Mnet>

L<Mnet::Log>

L<Mnet::Opts>

L<Mnet::Opts::Cli>

L<Mnet::Opts::Set>

=cut

# normal end of package
1;

